@@ -38,8 +38,14 @@ register(CoreOfficeSession)
 CoreTransSession = scoped_session(sessionmaker())
 register(CoreTransSession)
 
-# empty dict for now, this must populated on app startup
+CoreTransArchiveSession = scoped_session(sessionmaker())
+register(CoreTransArchiveSession)
+
+# empty dict for now, this may be populated on app startup
 ExtraCoreOfficeSessions = {}
 
-# empty dict for now, this must populated on app startup
+# empty dict for now, this may be populated on app startup
 ExtraCoreTransSessions = {}
+
+# empty dict for now, this may be populated on app startup
+ExtraCoreTransArchiveSessions = {}
