@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,4 +26,11 @@ Web Views
 
 
 def includeme(config):
-    config.include('tailbone_corepos.views.corepos')
+    config.include('tailbone_corepos.views.customers')
+    config.include('tailbone_corepos.views.departments')
+    config.include('tailbone_corepos.views.members')
+    config.include('tailbone_corepos.views.people')
+    config.include('tailbone_corepos.views.products')
+    config.include('tailbone_corepos.views.stores')
+    config.include('tailbone_corepos.views.subdepartments')
+    config.include('tailbone_corepos.views.vendors')
