@@ -89,6 +89,7 @@ class CoreMemberBatchView(BatchMasterView):
     row_form_fields = [
         'sequence',
         'card_number',
+        'card_number_raw',
         'status_code',
         'status_text',
     ]
@@ -155,6 +156,9 @@ class CoreMemberBatchView(BatchMasterView):
                 else:
                     kwargs['core_office_why_no_url'] = "URL not defined for this object"
 
+        else:
+            kwargs['core_office_why_no_url'] = "Card number not valid"
+
         return kwargs
 
 
