@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -88,5 +88,12 @@ class DepartmentView(CoreOfficeMasterView):
             office_url, department.number)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    DepartmentView = kwargs.get('DepartmentView', base['DepartmentView'])
     DepartmentView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
